@@ -3,6 +3,7 @@ from airflow import utils as airflow_utils, AirflowException
 
 from execution import runMapping
 from InformaticaPlugin.operators import available_arguments
+import os
 
 
 class ExecuteMapping(BaseOperator):
@@ -10,12 +11,13 @@ class ExecuteMapping(BaseOperator):
     @airflow_utils.apply_defaults
     def __init__(self, **kwargs):
         self.infa_arguments = []
+        self.pre_command = None
         for key, value in kwargs.items():
-            if key in available_arguments:
-                self.infa_arguments.append(available_arguments[key] + " " + '"' + value + '"')
+            if key == 'target':
+                self.pre_command = '. ' + os.environ.get('configDir', '.') + '/scheduler_env.' + value + '.sh'
             else:
-                print(
-                    "unrecognized key >" + key + "< provided. Its provided value is >" + value + "<. Argument IGNORED.")
+                if key in available_arguments:
+                    self.infa_arguments.append(available_arguments[key] + " " + value)
 
         super(ExecuteMapping, self).__init__(
             **kwargs)
@@ -25,10 +27,14 @@ class ExecuteMapping(BaseOperator):
         print("dag_id: " + self.dag_id)
         print("task_type: " + self.task_type)
         print("task id: " + self.task_id)
-        print("infa_arguments count: " + str(self.infa_arguments.count()))
-        print("infa_arguments: " + self.infa_arguments)
+        print("infa_arguments: " + ' '.join(self.infa_arguments))
+        if self.pre_command is None:
+            print("no pre_command provided.")
+        else:
+            print("pre_command: " + self.pre_command)
 
-        infa = runMapping.ExecuteInformaticaMapping(self.infa_arguments, False)
+        infa = runMapping.ExecuteInformaticaMapping(self.infa_arguments, log_on_console=False,
+                                                    pre_command=self.pre_command)
         result = infa.runit(infa.arguments)
         if result.rc != 0:
             raise AirflowException("RunMapping failed: " + result.message)
